==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_attach.js <==
_me = obj_attach.prototype;
function obj_attach(){};

/**
 * @date : 14.7.2006 10:26:59
 **/
_me.__constructor = function(){
	var me = this;
	this.__idtable = [];

	// PUBLIC
	this._aid;
	this._fid;
	this._iid;

	// CREATE FRAME
	this.__eFrame = document.getElementById(this._anchors['frame']);

		// STOP FRAME
		if (this.__eFrame.contentWindow.stop)
			this.__eFrame.contentWindow.stop();
		else{
			var doc = this.__eFrame.contentDocument;
			if (doc == undefined || doc == null)
				doc = this.__eFrame.contentWindow.document;

			doc.execCommand('Stop');
			doc = null;
		}

	this.__eAttach = document.getElementById(this._anchors['attach']);
	
	if (this.__eAttach){
		this.__eAttach.onclick = function(e){
	         var e = e || window.event;
	         var elm = e.target || e.srcElement;
	             elm = elm.parentNode;
			 if (elm.tagName != 'A') return false;

			 var id = me.__getId(elm.id);
			 /*
			 if (e.type == 'dblclick'){
				 if (me._ondblclick) me._ondblclick(e,elm,id,me.__idtable[id]);
				 else{
					 me.__eFrame.src = 'server/download.php?sid='
					 				   + dataSet.get('main',['sid'])
					 				   + '&aid='+me._aid
									   + '&fid='+me._fid
									   + '&iid='+me._iid
									   + '&pid='+me.__idtable[id].id;
				 }
	 	   	 }
			 else
			 */
			 if (me._onclick) me._onclick(e,elm,id,me.__idtable[id]);

			 me.__exeEvent('onclick',e,{"arg":me.__idtable[id],"elm":elm,"id":id,"owner":me});

			 return false;
		};

	    this.__eAttach.oncontextmenu = this.__eAttach.onclick;
		this.__eAttach.ondblclick 	 = this.__eAttach.onclick;
	}

	/*
    this._form	= document.forms[this._anchors['form']];

	if (this._form && this._form.file && this._form.file.onclick){
		var btn = this._getAnchor('button');
		if (btn){
			btn.onclick = function(e){
			    document.title += '*';
				this._form.file.onclick(e);
			};
		}
	}
	*/
};

/* Hopefully, this code could be removed some day :-) (Tonda, 19.6.2007)
_me._onclick = function(e,eid,id,idtable){
	if (e.type == 'contextmenu') return;
	var aUrl = {'sid':dataSet.get('main',['sid']),'class':'attachment','fullpath':this._aid+'/'+this._fid+'/'+this._iid+'/'+idtable['id']};

	downloadItem(buildURL(aUrl)); //or this.__eFrame.src = 'server/download.php?'+buildURL(aUrl);
};
*/

/**
 * @param: aArg - size,name,aid,fid,iid
 */
_me._add = function(aArg){

	if (this.__eIN && this.__eIN.disabled == true){
		this.__eIN.disabled = false;
		if (this._onuploadend) this._onuploadend();
	}

	var id = this.__idtable.length;
	this._addGuiElement(aArg, id);

	this.__idtable[id] = aArg;
};

_me._addGuiElement = function(aArg,id) {
	if (!this.__eAttach) return;

	var att = mkElement('a',{"href":'',"id":this.__getElmId(id)});
	if (aArg.size)
		att.innerHTML = '<span>' + aArg.name +' ('+ Math.ceilFloat(aArg.size/1024,1) +'kB);'+ '</span>';
	else
		att.innerHTML = '<span>' + aArg.name +';'+ '</span>';

	this.__eAttach.appendChild(att);
	
	if (this._onchange) this._onchange();
};

_me._removeGuiElement = function(id){
	this._getAnchor('attach').removeChild(document.getElementById(this.__getElmId(id)));

	if (this._onchange) this._onchange();
};

_me._value = function(v){

	if (v){
		if (v['aid']){
			this.aid = v['aid'];
			delete this.aid;
		}

		if (v['fid']){
			this.fid = v['fid'];
			delete this.fid;
		}

		if (v['iid']){
			this.iid = v['iid'];
			delete this.iid;
		}

		if (Is.Array(v['attachments'])){
			for (var i in v['attachments'])
				this._add(v['attachments'][i]);
		}
	}
	else
		return {'aid':this._aid,'fid':this._fid,'iid':this._fid,'attachments':this.__idtable};

};

   /**
    * @brief: return DOM Element ID
    **/
   _me.__getElmId = function (id){
	  return this._pathName +'/'+ id;
   };
   /**
    * @brief: return obj ID
    **/
   _me.__getId = function (eid){
	  return eid.substr(this._pathName.length+1);
   };
   /**
    * @brief: return attributes for given obj. ID
    **/
   _me.__getArgument = function(id){
	  return this.__idtable[id];
   };






/*
   NEMAZAT!!!!!!!!!

_me.__constructor = function(){

	 this._value("asdasdas;asdasd;asd;asdasdasd;asdasdasd;asdasasd");
}
_me._onfocus = function(e){

     var cart = this._getCartPos();

  	 var txt = this._value();
  	 var len = txt.length;
	 var pos = txt.indexOf(';',cart);

	 if (pos == -1){
		 if (len){
		 	 this._setRange(len);
		 	 //this._value(txt + ';');
 		 }
	 }
	 else{
         this._setRange(pos+1);
	 }
};
_me._onkeydown = function(e){

     var cart = this._getCartPos();
	 var text = this._value();

	 switch(e.keyCode){
	   case 37: //back
				  if(cart<1) return;

				  var str = text.substr(0,cart-1);
	              var pos = str.lastIndexOf(';');
	              if (pos>-1){
	                  this._setRange(pos+2);
					  return true;
				  }

	              break;
	   case 39: //front
	              var str = text.substr(cart);
	              var pos = str.indexOf(';');

				  if (pos>-1)
	                  this._setRange(cart+0+pos);
				  else
					  this._setRange(text.length);

				  return true;
	   case 8 : //backspace
	              if (!cart) break;
	              var str = text.substr(0,cart-1);
	              var pos = str.lastIndexOf(';');
	              if (pos<1){
					  this._value(text.substr(cart+1));
					  if ((pos = this._value().indexOf(';'))>-1){
		// alert(pos);
						   this._setRange(pos+1);
					  }
					  else
					  	 this._setRange(this._value().length);
				  }
				  else{
					  //this._value(text.substr(0,pos)+);
				  }

		//		  this._value(text.substr())
	              return false;
	   case 46: //delete
	              break;

	 }
	 return false;
}
_me._addAttach = function(sName,iSize){
	 // into object
	 this._value((this._value()?this._value()+';':'')+sName+' ('+iSize+'kB)');

	 // into server
	 if(this._onupload) this._onupload(sName,iSize);
};

*/

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_attach.js <==
_me = obj_attach.prototype;
function obj_attach(){};

/**
 * @date : 14.7.2006 10:26:59
 **/
_me.__constructor = function(){
	var me = this;
	this.__idtable = [];

	// PUBLIC
	this._aid;
	this._fid;
	this._iid;

	// CREATE FRAME
	this.__eFrame = document.getElementById(this._anchors['frame']);

		// STOP FRAME
		if (this.__eFrame.contentWindow.stop)
			this.__eFrame.contentWindow.stop();
		else{
			var doc = this.__eFrame.contentDocument;
			if (doc == undefined || doc == null)
				doc = this.__eFrame.contentWindow.document;

			doc.execCommand('Stop');
			doc = null;
		}

	this.__eAttach = document.getElementById(this._anchors['attach']);
	
	if (this.__eAttach){
		this.__eAttach.onclick = function(e){
	         var e = e || window.event;
	         var elm = e.target || e.srcElement;
	             elm = elm.parentNode;
			 if (elm.tagName != 'A') return false;

			 var id = me.__getId(elm.id);
			 /*
			 if (e.type == 'dblclick'){
				 if (me._ondblclick) me._ondblclick(e,elm,id,me.__idtable[id]);
				 else{
					 me.__eFrame.src = 'server/download.php?sid='
					 				   + dataSet.get('main',['sid'])
					 				   + '&aid='+me._aid
									   + '&fid='+me._fid
									   + '&iid='+me._iid
									   + '&pid='+me.__idtable[id].id;
				 }
	 	   	 }
			 else
			 */
			 if (me._onclick) me._onclick(e,elm,id,me.__idtable[id]);

			 me.__exeEvent('onclick',e,{"arg":me.__idtable[id],"elm":elm,"id":id,"owner":me});

			 return false;
		};

	    this.__eAttach.oncontextmenu = this.__eAttach.onclick;
		this.__eAttach.ondblclick 	 = this.__eAttach.onclick;
	}

	/*
    this._form	= document.forms[this._anchors['form']];

	if (this._form && this._form.file && this._form.file.onclick){
		var btn = this._getAnchor('button');
		if (btn){
			btn.onclick = function(e){
			    document.title += '*';
				this._form.file.onclick(e);
			};
		}
	}
	*/
};

/* Hopefully, this code could be removed some day :-) (Tonda, 19.6.2007)
_me._onclick = function(e,eid,id,idtable){
	if (e.type == 'contextmenu') return;
	var aUrl = {'sid':dataSet.get('main',['sid']),'class':'attachment','fullpath':this._aid+'/'+this._fid+'/'+this._iid+'/'+idtable['id']};

	downloadItem(buildURL(aUrl)); //or this.__eFrame.src = 'server/download.php?'+buildURL(aUrl);
};
*/

/**
 * @param: aArg - size,name,aid,fid,iid
 */
_me._add = function(aArg){

	if (this.__eIN && this.__eIN.disabled == true){
		this.__eIN.disabled = false;
		if (this._onuploadend) this._onuploadend(aArg);
	}

	var id = this.__idtable.length;
	this._addGuiElement(aArg, id);

	this.__idtable[id] = aArg;
};

_me._addGuiElement = function(aArg,id) {
	if (!this.__eAttach) return;

	var att = mkElement('a',{"href":'',"id":this.__getElmId(id)});
	if (aArg.size)
		att.innerHTML = '<span>' + aArg.name +' ('+ Math.ceilFloat(aArg.size/1024,1) +'kB);'+ '</span>';
	else
		att.innerHTML = '<span>' + aArg.name +';'+ '</span>';

	this.__eAttach.appendChild(att);
	
	if (this._onchange) this._onchange();
};

_me._removeGuiElement = function(id){

//alert('id: '+id+'\n'+this.__getElmId(id));

	this._getAnchor('attach').removeChild(document.getElementById(this.__getElmId(id)));

	if (this._onchange) this._onchange();
};

_me._value = function(v){

	if (v){
		if (v['aid']){
			this.aid = v['aid'];
			delete this.aid;
		}

		if (v['fid']){
			this.fid = v['fid'];
			delete this.fid;
		}

		if (v['iid']){
			this.iid = v['iid'];
			delete this.iid;
		}

		if (Is.Array(v['attachments'])){
			for (var i in v['attachments'])
				this._add(v['attachments'][i]);
		}
	}
	else
		return {'aid':this._aid,'fid':this._fid,'iid':this._fid,'attachments':this.__idtable};

};

   /**
    * @brief: return DOM Element ID
    **/
   _me.__getElmId = function (id){
	  return this._pathName +'/'+ id;
   };
   /**
    * @brief: return obj ID
    **/
   _me.__getId = function (eid){
	  return eid.substr(this._pathName.length+1);
   };
   /**
    * @brief: return attributes for given obj. ID
    **/
   _me.__getArgument = function(id){
	  return this.__idtable[id];
   };






/*
   NEMAZAT!!!!!!!!!

_me.__constructor = function(){

	 this._value("asdasdas;asdasd;asd;asdasdasd;asdasdasd;asdasasd");
}
_me._onfocus = function(e){

     var cart = this._getCartPos();

  	 var txt = this._value();
  	 var len = txt.length;
	 var pos = txt.indexOf(';',cart);

	 if (pos == -1){
		 if (len){
		 	 this._setRange(len);
		 	 //this._value(txt + ';');
 		 }
	 }
	 else{
         this._setRange(pos+1);
	 }
};
_me._onkeydown = function(e){

     var cart = this._getCartPos();
	 var text = this._value();

	 switch(e.keyCode){
	   case 37: //back
				  if(cart<1) return;

				  var str = text.substr(0,cart-1);
	              var pos = str.lastIndexOf(';');
	              if (pos>-1){
	                  this._setRange(pos+2);
					  return true;
				  }

	              break;
	   case 39: //front
	              var str = text.substr(cart);
	              var pos = str.indexOf(';');

				  if (pos>-1)
	                  this._setRange(cart+0+pos);
				  else
					  this._setRange(text.length);

				  return true;
	   case 8 : //backspace
	              if (!cart) break;
	              var str = text.substr(0,cart-1);
	              var pos = str.lastIndexOf(';');
	              if (pos<1){
					  this._value(text.substr(cart+1));
					  if ((pos = this._value().indexOf(';'))>-1){
		// alert(pos);
						   this._setRange(pos+1);
					  }
					  else
					  	 this._setRange(this._value().length);
				  }
				  else{
					  //this._value(text.substr(0,pos)+);
				  }

		//		  this._value(text.substr())
	              return false;
	   case 46: //delete
	              break;

	 }
	 return false;
}
_me._addAttach = function(sName,iSize){
	 // into object
	 this._value((this._value()?this._value()+';':'')+sName+' ('+iSize+'kB)');

	 // into server
	 if(this._onupload) this._onupload(sName,iSize);
};

*/
